@@ -199,7 +199,7 @@ perf_mddsPLS <- function(Xs,Y,lambda_min=0,lambda_max=NULL,n_lambda=1,lambdas=NU
       for(ii in 1:max(fold)){
         i_fold_ii <- which(fold==ii)
         hihi <- unlist(strsplit(as.character(err_char[ii]),split = " ",fixed = TRUE))
-        for(jj in 1:length(hihi)){
+        for(jj in 1:length (i_fold_ii)){#(hihi)){
           mat_errors[i_fold_ii[jj],] <- unlist(strsplit(hihi[jj],split = "/",fixed = TRUE))
         }
       }
@@ -207,8 +207,13 @@ perf_mddsPLS <- function(Xs,Y,lambda_min=0,lambda_max=NULL,n_lambda=1,lambdas=NU
       FREQ_OUT[i,] <- colSums(ERRORS[pos_in_errors,1:nlevels(Y)+4,drop=FALSE])
     }
   }
-  out <- list(RMSEP=cbind(paras_out,ERRORS_OUT),FREQ=cbind(paras_out,FREQ_OUT),
-              Conv=ERRORS[,c(1:3,ncol(ERRORS)-1)],time=ERRORS[,c(1:3,ncol(ERRORS))],mode=mode,Xs=Xs,Y=Y)
+  if(mode=="reg"){
+    out <- list(RMSEP=cbind(paras_out,ERRORS_OUT),FREQ=cbind(paras_out,FREQ_OUT),
+                Conv=ERRORS[,c(1:3,ncol(ERRORS)-1)],time=ERRORS[,c(1:3,ncol(ERRORS))],mode=mode,Xs=Xs,Y=Y)
+  }else{
+    out <- list(ERROR=cbind(paras_out,ERRORS_OUT),FREQ=cbind(paras_out,FREQ_OUT),
+                Conv=ERRORS[,c(1:3,ncol(ERRORS)-1)],time=ERRORS[,c(1:3,ncol(ERRORS))],mode=mode,Xs=Xs,Y=Y)
+  }
   class(out) <- "perf_mddsPLS"
   out
 }
